@@ -1,5 +1,4 @@
-surfaceTraitPlot<-
-function(dat,hansenfit,whattraits=c(1,2),cols=NULL, convcol=TRUE,pchs=c(21,21),cex.opt=2.5,optellipses=FALSE, ellipsescale=1,y.lim=NULL,x.lim=NULL,y.lab=NULL,x.lab=NULL,...){
+surfaceTraitPlot<-function(dat,hansenfit,whattraits=c(1,2),cols=NULL, convcol=TRUE,pch.pt=21,pch.opt=21,cex.opt=2.5,optellipses=FALSE, ellipsescale=1,y.lim=NULL,x.lim=NULL,y.lab=NULL,x.lab=NULL,...){
 
 	fit<-hansenfit$fit
 	if(length(fit)>1|class(fit)=="list")fit<-fit[[1]]
@@ -15,20 +14,19 @@ if(is.null(cols)){
 	if(convcol){
 		cols<-character(length(xx))
 		cols[xx>1]<-rainbow(sum(xx>1))
-		if(any(xx==1))	
-			cols[xx==1]<-c("black",grey(seq(0.7,0.3,length.out=sum(xx==1)-1)))
+		cols[xx==1]<-c("black",grey(seq(0.7,0.3,length.out=sum(xx==1)-1)))
 	}else{
 		cols<-c("black",rainbow(length(xx)-1))
 	}	}
 
-	if(pchs[1]%in%(21:25)){
+	if(pch.pt[1]%in%(21:25)){
 		datbg<-cols[as.numeric(factor(otree2[,5]))]
 		datcols<-rep("black",length(datbg))
 	}else{
 		datcols<-cols[as.numeric(factor(otree2[,5]))]
 		datbg<-rep("black",length(datcols))
 	}
-	if(pchs[2]%in%(21:25)){
+	if(pch.opt%in%(21:25)){
 		optcols<-rep("black",length(cols))
 		optbg<-cols
 	}else{
@@ -45,16 +43,7 @@ if(is.null(cols)){
 		widths<-rep(0,dim(dat)[2])
 	}
 
-if(dim(optima)[2]==1)whattraits<-1
-	x<-whattraits[1]
-if(length(whattraits)==1){
-	dat<-data.frame(dat[,x,drop=F],Regime=as.numeric(factor(otree2[,5])))
-	optima<-data.frame(optima[,x,drop=F],Regime=as.numeric(factor(rownames(optima))))
-	widths<-c(widths[x],0.4/ellipsescale[1])
-	x<-1;y<-2
-}else{
-	y<-whattraits[2]
-}
+	x<-whattraits[1];y<-whattraits[2]
 	if(is.null(y.lim))
 		y.lim<-range(c(dat[,y],optima[,y]+widths[y]*ellipsescale[1],optima[,y]-widths[y]*ellipsescale[1]))
 	if(is.null(x.lim))
@@ -70,7 +59,7 @@ if(length(whattraits)==1){
 			ye<-optima[i,y]+ellipsescale[j]*widths[y]*sin(ae)
 			polygon(x=xe,y=ye,col=cols[i])
 	}}	}else{
-	points(optima[,x],optima[,y],pch=pchs[2],col=optcols,bg=optbg,cex=cex.opt)
+	points(optima[,x],optima[,y],pch=pch.opt,col=optcols,bg=optbg,cex=cex.opt)
 		}
-	points(dat[,x],dat[,y],col=datcols,bg=datbg,pch=pchs[1],...)
+	points(dat[,x],dat[,y],col=datcols,bg=datbg,pch=pch.pt,...)
 }
\ No newline at end of file
